@@ -137,7 +137,7 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
                    "A plugin for browsing DLNA servers",
                    "Intel Corp.",
                    VERSION,
-                   "LGPL",
+                   "LGPL-2.1-or-later",
                    "https://01.org/dleyna",
                    grl_dleyna_plugin_init,
                    grl_dleyna_plugin_deinit,
