@@ -246,7 +246,7 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
                    "A plugin for searching multimedia content using Rai.tv",
                    "Marco Piazza",
                    VERSION,
-                   "LGPL",
+                   "LGPL-2.1-or-later",
                    "https://wiki.gnome.org/Projects/Grilo",
                    grl_raitv_plugin_init,
                    NULL,
