@@ -606,7 +606,7 @@ grl_tracker_build_resource_from_media (GrlMedia *media, GList *keys)
 
         mb_release_id = grl_media_get_mb_release_id (media);
         if (mb_release_id) {
-          ensure_resource_for_musicbrainz_tag (resource,
+          ensure_resource_for_musicbrainz_tag (album,
                                                "https://musicbrainz.org/doc/Release",
                                                mb_release_id);
         }
@@ -617,7 +617,7 @@ grl_tracker_build_resource_from_media (GrlMedia *media, GList *keys)
 
         mb_release_group_id = grl_media_get_mb_release_group_id (media);
         if (mb_release_group_id) {
-          ensure_resource_for_musicbrainz_tag (resource,
+          ensure_resource_for_musicbrainz_tag (album,
                                                "https://musicbrainz.org/doc/Release_Group",
                                                mb_release_group_id);
         }
@@ -661,12 +661,15 @@ grl_tracker_build_resource_from_media (GrlMedia *media, GList *keys)
       tracker_resource_set_string (hash, "nfo:hashValue",
                                    grl_data_get_string (GRL_DATA (media), grl_metadata_key_chromaprint));
     } else if (l->data == GRLKEYID_TO_POINTER (GRL_METADATA_KEY_ARTIST)) {
-      TrackerResource *artist;
+      TrackerResource *artist = NULL;
       const gchar *artist_name;
-      gint i;
+      gint i = 0;
 
-      for (i = 0; artist_name != NULL; i++) {
+      while (TRUE) {
         artist_name = grl_media_get_artist_nth (media, i);
+        if (!artist_name)
+          break;
+
         artist = ensure_resource_for_property (resource, "nmm:artist", TRUE);
         tracker_resource_set_string (artist, "nmm:artistName", artist_name);
 
@@ -676,31 +679,40 @@ grl_tracker_build_resource_from_media (GrlMedia *media, GList *keys)
 
           mb_artist_id = grl_media_get_mb_artist_id_nth (media, i);
           if (mb_artist_id) {
-            ensure_resource_for_musicbrainz_tag (resource,
+            ensure_resource_for_musicbrainz_tag (artist,
                                                  "https://musicbrainz.org/doc/Artist",
                                                  mb_artist_id);
           }
         }
+        i++;
       }
     } else if (l->data == GRLKEYID_TO_POINTER (GRL_METADATA_KEY_AUTHOR)) {
       TrackerResource *artist;
       const gchar *artist_name;
-      gint i;
+      gint i = 0;
 
-      for (i = 0; artist_name != NULL; i++) {
+      while (TRUE) {
         artist_name = grl_media_get_artist_nth (media, i);
+        if (!artist_name)
+          break;
+
         artist = ensure_resource_for_property (resource, "nmm:artist", TRUE);
         tracker_resource_set_string (artist, "nmm:artistName", artist_name);
+        i++;
       }
     } else if (l->data == GRLKEYID_TO_POINTER (GRL_METADATA_KEY_COMPOSER)) {
       TrackerResource *composer;
       const gchar *composer_name;
-      gint i;
+      gint i = 0;
 
-      for (i = 0; composer_name != NULL; i++) {
+      while (TRUE) {
         composer_name = grl_media_get_composer_nth (media, i);
+        if (!composer_name)
+          break;
+
         composer = ensure_resource_for_property (resource, "nmm:composer", TRUE);
         tracker_resource_set_string (composer, "nmm:artistName", composer_name);
+        i++;
       }
     }
   }
